
From: Jeff Dike <jdike@addtoit.com>

Use for_each_cpu rather than iterating over processors by hand.

Signed-off-by: Jeff Dike <jdike@addtoit.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/um/kernel/irq.c |   10 ++++------
 25-akpm/arch/um/kernel/smp.c |    6 ++----
 2 files changed, 6 insertions(+), 10 deletions(-)

diff -puN arch/um/kernel/irq.c~uml-use-for_each_cpu arch/um/kernel/irq.c
--- 25/arch/um/kernel/irq.c~uml-use-for_each_cpu	2005-01-09 23:44:16.112713984 -0800
+++ 25-akpm/arch/um/kernel/irq.c	2005-01-09 23:44:16.117713224 -0800
@@ -45,9 +45,8 @@ int show_interrupts(struct seq_file *p, 
 
 	if (i == 0) {
 		seq_printf(p, "           ");
-		for (j=0; j<NR_CPUS; j++)
-			if (cpu_online(j))
-				seq_printf(p, "CPU%d       ",j);
+		for_each_cpu(j)
+			seq_printf(p, "CPU%d       ",j);
 		seq_putc(p, '\n');
 	}
 
@@ -60,9 +59,8 @@ int show_interrupts(struct seq_file *p, 
 #ifndef CONFIG_SMP
 		seq_printf(p, "%10u ", kstat_irqs(i));
 #else
-		for (j = 0; j < NR_CPUS; j++)
-			if (cpu_online(j))
-				seq_printf(p, "%10u ", kstat_cpu(j).irqs[i]);
+		for_each_cpu(j)
+			seq_printf(p, "%10u ", kstat_cpu(j).irqs[i]);
 #endif
 		seq_printf(p, " %14s", irq_desc[i].handler->typename);
 		seq_printf(p, "  %s", action->name);
diff -puN arch/um/kernel/smp.c~uml-use-for_each_cpu arch/um/kernel/smp.c
--- 25/arch/um/kernel/smp.c~uml-use-for_each_cpu	2005-01-09 23:44:16.114713680 -0800
+++ 25-akpm/arch/um/kernel/smp.c	2005-01-09 23:44:16.118713072 -0800
@@ -247,10 +247,8 @@ int smp_call_function(void (*_func)(void
 	func = _func;
 	info = _info;
 
-	for (i=0;i<NR_CPUS;i++)
-		if((i != current_thread->cpu) &&
-		   cpu_isset(i, cpu_online_map))
-			os_write_file(cpu_data[i].ipi_pipe[1], "C", 1);
+	for_each_cpu(i)
+		os_write_file(cpu_data[i].ipi_pipe[1], "C", 1);
 
 	while (atomic_read(&scf_started) != cpus)
 		barrier();
_
